Notation standards, References — Surprise 1 documentation

# Notation standards, References

In the documentation, you will find the following notation:

- \(R\) : the set of all ratings.
- \(R_{train}\), \(R_{test}\) and \(\hat{R}\) denote the training set, the test set, and the set of predicted ratings.
- \(U\) : the set of all users. \(u\) and \(v\) denotes users.
- \(I\) : the set of all items. \(i\) and \(j\) denotes items.
- \(U_i\) : the set of all users that have rated item \(i\).
- \(U_{ij}\) : the set of all users that have rated both items \(i\) and \(j\).
- \(I_u\) : the set of all items rated by user \(u\).
- \(I_{uv}\) : the set of all items rated by both users \(u\) and \(v\).
- \(r_{ui}\) : the true rating of user \(u\) for item \(i\).
- \(\hat{r}_{ui}\) : the estimated rating of user \(u\) for item \(i\).
- \(b_{ui}\) : the baseline rating of user \(u\) for item \(i\).
- \(\mu\) : the mean of all ratings.
- \(\mu_u\) : the mean of all ratings given by user \(u\).
- \(\mu_i\) : the mean of all ratings given to item \(i\).
- \(\sigma_u\) : the standard deviation of all ratings given by user \(u\).
- \(\sigma_i\) : the standard deviation of all ratings given to item \(i\).
- \(N_i^k(u)\) : the \(k\) nearest neighbors of user \(u\) that have rated item \(i\). This set is computed using a `similarity metric`.
- \(N_u^k(i)\) : the \(k\) nearest neighbors of item \(i\) that are rated by user \(u\). This set is computed using a `similarity metric`.

References

Here are the papers used as references in the documentation. Links to pdf files where added when possible. A simple Google search should lead you easily to the missing ones :)

[GM05] | Thomas George and Srujana Merugu. A scalable collaborative filtering framework based on co-clustering. 2005. URL: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.113.6458&rep=rep1&type=pdf.

[Kor08] | Yehuda Koren. Factorization meets the neighborhood: a multifaceted collaborative filtering model. 2008. URL: http://www.cs.rochester.edu/twiki/pub/Main/HarpSeminar/Factorization_Meets_the_Neighborhood-_a_Multifaceted_Collaborative_Filtering_Model.pdf.

[Kor10] | Yehuda Koren. Factor in the neighbors: scalable and accurate collaborative filtering. 2010. URL: http://courses.ischool.berkeley.edu/i290-dm/s11/SECURE/a1-koren.pdf.

[KBV09] | Yehuda Koren, Robert Bell, and Chris Volinsky. Matrix factorization techniques for recommender systems. 2009.

[LS01] | Daniel D. Lee and H. Sebastian Seung. Algorithms for non-negative matrix factorization. 2001. URL: http://papers.nips.cc/paper/1861-algorithms-for-non-negative-matrix-factorization.pdf.

[LM07] | Daniel Lemire and Anna Maclachlan. Slope one predictors for online rating-based collaborative filtering. 2007. URL: http://arxiv.org/abs/cs/0702144.

[LZXZ14] | Xin Luo, Mengchu Zhou, Yunni Xia, and Qinsheng Zhu. An efficient non-negative matrix factorization-based approach to collaborative filtering for recommender systems. 2014.

[RRSK10] | Francesco Ricci, Lior Rokach, Bracha Shapira, and Paul B. Kantor. Recommender Systems Handbook. 1st edition, 2010.

[SM08] | Ruslan Salakhutdinov and Andriy Mnih. Probabilistic matrix factorization. 2008. URL: http://papers.nips.cc/paper/3208-probabilistic-matrix-factorization.pdf.

[ZWFM96] | Sheng Zhang, Weihong Wang, James Ford, and Fillia Makedon. Learning from incomplete ratings using non-negative matrix factorization. 1996. URL: http://www.siam.org/meetings/sdm06/proceedings/059zhangs2.pdf.